===============================
montague_testapps
===============================

These are test applications and other entry points for the
`Montague <https://pypi.python.org/pypi/montague>`__ configuration
loading library. Most of them were extracted from the PasteDeploy test
suite.

They are a separate package so they can be used by multiple Montague
packages.
